@@ -1,4 +1,4 @@
-/* mcparameters.h -- This file is part of Archimedes release 1.0.0.
+/* mcparameters.h -- This file is part of Archimedes release 1.1.0.
    Archimedes is a simulator for Submicron 2D III-V semiconductor
    Devices. It implements the Monte Carlo method
    for the simulation of the semiclassical Boltzmann equation for both
@@ -6,7 +6,7 @@
    of effective potential method. It is now able to simulate applied
    magnetic fields along with self consistent Faraday equation.
 
-   Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Jean Michel Sellier <jeanmichel.sellier@gmail.com>
+   Copyright (C) 2004-2011 Jean Michel Sellier <jeanmichel.sellier@gmail.com>
  
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
 
 // ######################################################
 // Created on 05 sep.2004, Siracusa, J.M.Sellier
-// Last modif. : 12 Aug.2011, Carry le Rouet, France, J.M.Sellier
+// Last modif. : 18 Aug.2011, Carry le Rouet, France, J.M.Sellier
 // ######################################################
 
 // Definition of the variables needed for taking into
@@ -100,10 +100,11 @@ MCparameters(int Material)
 
 // Calculation of scattering rates
   for(ie=1;ie<=DIME;ie++){
-    initialenergy=DE*((real)(ie));
-    sei=sqrt(initialenergy);
+   initialenergy=DE*((real)(ie));
+   sei=sqrt(initialenergy);
 // GAMMA-valley
 // ============
+   if(OPTICALPHONONS==ON){
 // Polar optical phonon
 // Emission - Parabolic
     finalenergy=initialenergy-HWO[Material][0];
@@ -137,12 +138,27 @@ MCparameters(int Material)
                             +z2*opa*sef*dos2*(1.+2.*alphaK[Material][2]*finalenergy);
     }
     else SWK[Material][1][4][ie]=SWK[Material][1][3][ie];
+   }
+   else{
+    // NO OPTICAL SCATTERING
+    SWK[Material][1][1][ie]=0.0;
+    SWK[Material][1][2][ie]=0.0;
+    SWK[Material][1][3][ie]=0.0;
+    SWK[Material][1][4][ie]=0.0;
+   }
+   if(ACOUSTICPHONONS==ON){
 // Acoustic Phonon
     finalenergy=initialenergy;
     sef=sqrt(finalenergy*(1.+alphaK[Material][1]*finalenergy));
     SWK[Material][1][5][ie]=SWK[Material][1][4][ie]
                            +aco*sef*dos1*(1.+2.*alphaK[Material][1]*finalenergy);
+   }
+   else {
+    // NO ACOUSTIC PHONON
+    SWK[Material][1][5][ie]=SWK[Material][1][4][ie]+0.0;
+   }
 // Impurity scattering
+   if(IMPURITYPHONONS==ON){
     finalenergy=initialenergy;
     sef=sqrt(finalenergy*(1.+alphaK[Material][1]*finalenergy));
     ak=SMH[Material][1]*sef;
@@ -150,9 +166,14 @@ MCparameters(int Material)
     wk=bimp/qq*sef*dos1*(1.+2.*alphaK[Material][1]*finalenergy);
     if(wk>1.e14) wk=1.e14;
     SWK[Material][1][6][ie]=SWK[Material][1][5][ie]+wk;
-
+   }
+   else {
+    // NO IMPURITY SCATTERING
+    SWK[Material][1][6][ie]=SWK[Material][1][5][ie]+0.0;
+   }
 // L-valley
 // ========
+   if(OPTICALPHONONS==ON){
 // Polar optical phonon
 // Emission
     finalenergy=initialenergy-HWO[Material][0];
@@ -201,15 +222,32 @@ MCparameters(int Material)
                             +opa*sef*dos1*(1.+2.*alphaK[Material][2]*finalenergy);
     }
     else SWK[Material][2][6][ie]=SWK[Material][2][5][ie];
+   }
+   else {
+      // NO OPTICAL SCATTERING
+      SWK[Material][2][1][ie]=0.0;
+      SWK[Material][2][2][ie]=0.0;
+      SWK[Material][2][3][ie]=0.0;
+      SWK[Material][2][4][ie]=0.0;
+      SWK[Material][2][5][ie]=0.0;
+      SWK[Material][2][6][ie]=0.0;
+   }
+   if(ACOUSTICPHONONS==ON){
 // Acoustic phonon
     finalenergy=initialenergy;
     sef=sqrt(finalenergy*(1.+alphaK[Material][2]*finalenergy));
     SWK[Material][2][7][ie]=SWK[Material][2][6][ie]
                            +aco*sef*dos2*(1.+2.*alphaK[Material][2]*finalenergy);
+   }
+   else {
+      // NO ACOUSTIC SCATTERING
+      SWK[Material][2][7][ie]=SWK[Material][2][6][ie]+0.0;
+   }
 // ==================
 // --->  } <--- This is a bug! Removed by J.M.Sellier on 24 dec.2006 (SR)
-// (Thanks to Kun-Yuan Xu who helped me in finding it!)
+// (Thanks to Kun-Yuan Xu who helped me to find it!)
 // ==================
+   if(IMPURITYPHONONS==ON){
 // Impurity scattering
     finalenergy=initialenergy;
     sef=sqrt(finalenergy*(1.+alphaK[Material][2]*finalenergy));
@@ -218,6 +256,11 @@ MCparameters(int Material)
     wk=bimp/qq*sef*dos2*(1.+2.*alphaK[Material][2]*finalenergy);
     if(wk>1.e14) wk=1.e14;
     SWK[Material][2][8][ie]=SWK[Material][2][7][ie]+wk;
+   }
+   else {
+    // NO IMPURITY SCATTERING
+    SWK[Material][2][8][ie]=SWK[Material][2][7][ie]+0.0;
+   }
   } // <--- this is the correct place for the symbol } (J.M.Sellier,24/12/2006)
 // Evalutation of gamma
   GM[Material]=SWK[Material][1][6][1];
@@ -248,7 +291,7 @@ MCparameters(int Material)
   aco=2.*PI*(DA[Material]/Q)*DA[Material]*(BKTQ/HBAR)
      *(Q/(RHO[Material]*UL[Material]*UL[Material]));
 // Constants for the 6 Silicon-like non-polar optical phonons
-  for(i=1;i<=6;i++){
+   for(i=1;i<=6;i++){
 // i-th Optical Phonon
     oge[i]=0.;
     oga[i]=0.;
@@ -259,36 +302,58 @@ MCparameters(int Material)
             *((DTK[Material][i-1]*Q/RHO[Material])/Q)*(no+1.);
       oga[i]=oge[i]*no/(1.+no);
     }
-  }
-// Calculation of scattering rates
- for(ie=1; ie<=DIME; ++ie) SWK[Material][0][0][ie]=0.;
- for(ie=1; ie<=DIME; ++ie){
-   initialenergy=DE*((real) ie);
-   sei=sqrt(initialenergy);
-// non polar optical phonons
-   for(i=1;i<=6;i++){
-     finalenergy=initialenergy-HWO[Material][i-1];
-     SWK[Material][0][i*2-1][ie]=SWK[Material][0][i*2-2][ie];
-     if(finalenergy>0.){
-      sef=sqrt(finalenergy*(1.+alphaK[Material][1]*finalenergy));
-      SWK[Material][0][i*2-1][ie]=SWK[Material][0][i*2-2][ie]
-                    +oge[i]*sef*dos*(1.+2.*alphaK[Material][1]*finalenergy);
-     }
-     finalenergy=initialenergy+HWO[Material][i-1];
-     SWK[Material][0][i*2][ie]=SWK[Material][0][i*2-1][ie];
-     if(finalenergy>0.){
-      sef=sqrt(finalenergy*(1.+alphaK[Material][1]*finalenergy));
-      SWK[Material][0][i*2][ie]=SWK[Material][0][i*2-1][ie]
-                  +oga[i]*sef*dos*(1.+2.*alphaK[Material][1]*finalenergy);
-     }
    }
+// Calculation of scattering rates
+   for(ie=1; ie<=DIME; ++ie) SWK[Material][0][0][ie]=0.;
+   for(ie=1; ie<=DIME; ++ie){
+    initialenergy=DE*((real) ie);
+    sei=sqrt(initialenergy);
+    if(OPTICALPHONONS==ON){
+// non polar optical phonons
+     for(i=1;i<=6;i++){
+      finalenergy=initialenergy-HWO[Material][i-1];
+      SWK[Material][0][i*2-1][ie]=SWK[Material][0][i*2-2][ie];
+      if(finalenergy>0.){
+       sef=sqrt(finalenergy*(1.+alphaK[Material][1]*finalenergy));
+       SWK[Material][0][i*2-1][ie]=SWK[Material][0][i*2-2][ie]
+                     +oge[i]*sef*dos*(1.+2.*alphaK[Material][1]*finalenergy);
+      }
+      finalenergy=initialenergy+HWO[Material][i-1];
+      SWK[Material][0][i*2][ie]=SWK[Material][0][i*2-1][ie];
+      if(finalenergy>0.){
+       sef=sqrt(finalenergy*(1.+alphaK[Material][1]*finalenergy));
+       SWK[Material][0][i*2][ie]=SWK[Material][0][i*2-1][ie]
+                   +oga[i]*sef*dos*(1.+2.*alphaK[Material][1]*finalenergy);
+      }
+     }
+    }
+    else {
+     // NO OPTICAL SCATTERING
+     SWK[Material][0][1][ie]=0.0;
+     SWK[Material][0][2][ie]=0.0;
+     SWK[Material][0][3][ie]=0.0;
+     SWK[Material][0][4][ie]=0.0;
+     SWK[Material][0][5][ie]=0.0;
+     SWK[Material][0][6][ie]=0.0;
+     SWK[Material][0][7][ie]=0.0;
+     SWK[Material][0][8][ie]=0.0;
+     SWK[Material][0][9][ie]=0.0;
+     SWK[Material][0][10][ie]=0.0;
+     SWK[Material][0][11][ie]=0.0;
+     SWK[Material][0][12][ie]=0.0;
+    }
+    if(ACOUSTICPHONONS==ON){
 // Acoustic phonon
-   finalenergy=initialenergy;
-   sef=sqrt(finalenergy*(1.+alphaK[Material][1]*finalenergy));
-   SWK[Material][0][13][ie]=SWK[Material][0][12][ie]
-                 +aco*sef*dos*(1.+2.*alphaK[Material][1]*finalenergy);
-  }
-
+    finalenergy=initialenergy;
+    sef=sqrt(finalenergy*(1.+alphaK[Material][1]*finalenergy));
+    SWK[Material][0][13][ie]=SWK[Material][0][12][ie]
+                  +aco*sef*dos*(1.+2.*alphaK[Material][1]*finalenergy);
+    }
+    else {
+    // NO ACOUSTIC PHONONS 
+    SWK[Material][0][13][ie]=SWK[Material][0][12][ie]+0.0;
+    }
+   }
 // Evaluation of gamma
   GM[Material]=SWK[Material][0][13][1];
   for(ie=1;ie<=DIME;++ie)
